package router

import (
	hdl2 "applet/app/admin/hdl"
	hdl "applet/app/admin/hdl/enterprise_manage"
	"applet/app/admin/mw"
	"applet/app/cfg"
	"github.com/gin-gonic/gin"
)

// Init 初始化路由
func Init() *gin.Engine {
	mode := "release"
	if cfg.Debug {
		mode = "debug"
	}
	gin.SetMode(mode)
	//创建一个新的启动器
	r := gin.New()

	// 是否打印访问日志, 在非正式环境都打印
	if mode != "release" {
		r.Use(gin.Logger())
	}
	r.Use(gin.Recovery())

	r.GET("/favicon.ico", func(c *gin.Context) {
		c.Status(204)
	})
	r.NoRoute(func(c *gin.Context) {
		c.JSON(404, gin.H{"code": 404, "msg": "page not found", "data": []struct{}{}})
	})
	r.NoMethod(func(c *gin.Context) {
		c.JSON(405, gin.H{"code": 405, "msg": "method not allowed", "data": []struct{}{}})
	})
	r.Use(mw.Cors)
	AdminRoute(r.Group("/api/admin"))
	CustomerInit(r.Group("/api/v1"))
	return r
}

func rCompany(r *gin.RouterGroup) {
	r.GET("/list", hdl2.CompanyList)
	r.POST("/add", hdl2.CompanyAdd)
	r.POST("/update", hdl2.CompanyUpdate)
	r.DELETE("/delete/:id", hdl2.CompanyDelete)
}

func rHomePage(r *gin.RouterGroup) {
	r.GET("/index", hdl2.HomePageIndex)
	r.GET("/thisWeekData", hdl2.ThisWeekData)
	r.GET("/thisMonthData", hdl2.ThisMonthData)
}

func rNotice(r *gin.RouterGroup) {
	r.GET("/list", hdl2.NoticeList)
	r.POST("/add", hdl2.NoticeAdd)
	r.POST("/sort", hdl2.NoticeSort)
	r.POST("/update", hdl2.NoticeUpdate)
	r.DELETE("/delete/:id", hdl2.NoticeUpdate)
}

func rBanner(r *gin.RouterGroup) {
	r.GET("/list", hdl2.BannerList)
	r.POST("/add", hdl2.BannerAdd)
	r.POST("/sort", hdl2.BannerSort)
	r.POST("/update", hdl2.BannerUpdate)
	r.DELETE("/delete/:id", hdl2.BannerDelete)
}

func rComm(r *gin.RouterGroup) {
	r.POST("/getMenuList", hdl2.MenuList) // 获取菜单栏列表
}

func rOss(r *gin.RouterGroup) {
	r.POST("/upload/token", hdl2.ImgReqUpload) // 文件上传获取七牛云上传token
}

func rSetCenter(r *gin.RouterGroup) {
	r.GET("/get", hdl2.GetCenter)  // 设置中心-获取
	r.POST("/set", hdl2.SetCenter) // 设置中心-设置
}

func rAuditCenter(r *gin.RouterGroup) {
	r.POST("/centralKitchenForSchoolOrderRefundList", hdl2.CentralKitchenForSchoolOrderRefundList)   //审核中心-央厨-学校-订单退款列表
	r.POST("/centralKitchenForSchoolOrderRefundAudit", hdl2.CentralKitchenForSchoolOrderRefundAudit) //审核中心-央厨-学校-订单退款审核
	r.POST("/nursingHomeOrderRefundList", hdl2.NursingHomeOrderRefundList)                           //审核中心-养老院-订单退款列表
	r.POST("/nursingHomeOrderRefundAudit", hdl2.NursingHomeOrderRefundAudit)                         //审核中心-养老院-订单退款审核
}

func rFinanceManage(r *gin.RouterGroup) {
	r.POST("/centralKitchenForSchool/ordList", hdl.CentralKitchenForSchoolOrdList)                     //财务管理-(央厨-学校)订单列表
	r.GET("/centralKitchenForSchool/ordDetail", hdl.CentralKitchenForSchoolOrdDetail)                  //财务管理-(央厨-学校)订单详情
	r.POST("/centralKitchenForSchool/ordRefund", hdl.CentralKitchenForSchoolOrdRefund)                 //财务管理-(央厨-学校)订单退款
	r.POST("/selfSupportForSchool/ordList", hdl.SelfSupportForSchoolOrdList)                           //财务管理-(自营-学校)订单列表
	r.POST("/selfSupportForSchool/arrearsOrdList", hdl.SelfSupportForSchoolArrearsOrdList)             //财务管理-(自营-学校)欠费列表
	r.POST("/selfSupportForSchool/arrearsOrdDebtRepay", hdl.SelfSupportForSchoolArrearsOrdDebtRepay)   //"自营-学校"订单欠费催缴
	r.POST("/selfSupportForSchool/arrearsOrdDebtCancel", hdl.SelfSupportForSchoolArrearsOrdDebtCancel) //"自营-学校"撤销欠款
	r.POST("/nursingHome/ordList", hdl.NursingHomeOrdList)                                             //财务管理-(养老院)订单列表
	r.GET("/nursingHome/ordDetail", hdl.NursingHomeOrdDetail)                                          //财务管理-(养老院)订单详情
	r.POST("/nursingHome/ordRefund", hdl.NursingHomeOrdRefund)                                         //财务管理-(养老院)订单退款
}

func rDataStatistics(r *gin.RouterGroup) {
	r.POST("/centralKitchenForSchool/export", hdl2.CentralKitchenForSchoolDataStatisticsExport)       //数据统计-(央厨-学校)-导出
	r.POST("/centralKitchenForSchool/list", hdl2.CentralKitchenForSchoolDataStatisticsList)           //数据统计-(央厨-学校)-列表
	r.DELETE("/centralKitchenForSchool/delete/:id", hdl2.CentralKitchenForSchoolDataStatisticsDelete) //数据统计-(央厨-学校)-删除

	r.POST("/nursingHome/export", hdl2.NursingHomeDataStatisticsExport)       //数据统计-(养老院)-导出
	r.POST("/nursingHome/list", hdl2.NursingHomeDataStatisticsList)           //数据统计-(养老院)-列表
	r.DELETE("/nursingHome/delete/:id", hdl2.NursingHomeDataStatisticsDelete) //数据统计-(养老院)-删除

	r.POST("/selfSupportForSchool/export", hdl2.SelfSupportForSchoolDataStatisticsExport)       //数据统计-(自营-学校)-导出
	r.POST("/selfSupportForSchool/list", hdl2.SelfSupportForSchoolDataStatisticsList)           //数据统计-(自营-学校)-列表
	r.DELETE("/selfSupportForSchool/delete/:id", hdl2.SelfSupportForSchoolDataStatisticsDelete) //数据统计-(自营-学校)-删除

}

func rUser(r *gin.RouterGroup) {
	r.POST("/list", hdl2.UserList)                                                        //列表
	r.POST("centralKitchenForSchool/list", hdl2.CentralKitchenForSchoolUserList)          //央厨用户列表
	r.POST("/centralKitchenForSchool/userUpdate", hdl2.CentralKitchenForSchoolUserUpdate) //"央厨-学校"用户编辑
	r.POST("/centralKitchenForSchool/userDelete", hdl2.CentralKitchenForSchoolUserDelete) //"央厨-学校"用户删除

	r.POST("/update", hdl2.UserUpdate)       //编辑
	r.DELETE("/delete/:id", hdl2.UserDelete) //删除
}

func rEnterprise(r *gin.RouterGroup) {
	r.POST("/list", hdl2.EnterpriseList)
	r.POST("/add", hdl2.EnterpriseAdd)
	r.POST("/update", hdl2.EnterpriseUpdate)
	r.POST("/delete", hdl2.EnterpriseDelete)
	r.POST("/updateState", hdl2.EnterpriseUpdateState)
	r.POST("/addGrade", hdl2.EnterpriseAddGrade)
	r.GET("/detail", hdl2.Detail)
	r.GET("/schoolBelowGrade", hdl2.SchoolBelowGrade)                                                         //"学校"下年级
	r.GET("/schoolGradeBelowClass", hdl2.SchoolGradeBelowClass)                                               //"学校"年级下班级
	r.POST("/setCentralKitchenForSchoolWithSpecForSystem", hdl2.SetCentralKitchenForSchoolWithSpecForSystem)  //"央厨-学校-套餐-系统" 价格设置
	r.GET("/getCentralKitchenForSchoolWithSpecForSystem", hdl2.GetCentralKitchenForSchoolWithSpecForSystem)   //"央厨-学校-套餐-系统" 价格获取
	r.POST("/listCentralKitchenForSchoolPackageForSystem", hdl2.ListCentralKitchenForSchoolPackageForSystem)  //"央厨-学校-套餐-系统" 列表
	r.POST("/saveCentralKitchenForSchoolPackage", hdl2.SaveCentralKitchenForSchoolPackageForSystem)           //新增/编辑 "央厨-学校-套餐-系统"
	r.DELETE("/deleteCentralKitchenForSchoolPackage/:id", hdl2.DeleteCentralKitchenForSchoolPackageForSystem) //删除 "央厨-学校-套餐-系统"
	r.POST("/syncCentralKitchenForSchoolPackageForSystem", hdl2.SyncCentralKitchenForSchoolPackageForSystem)  //"央厨-学校-套餐-系统" 同步数据
}

func rEnterpriseManage(r *gin.RouterGroup) {
	r.GET("/info", hdl.EnterpriseManageInfo)                                             //校企管理信息
	r.POST("/userIdentityList", hdl.UserIdentityList)                                    //用户列表
	r.POST("/centralKitchenForSchool/userUpdate", hdl.CentralKitchenForSchoolUserUpdate) //"央厨-学校"用户编辑
	r.POST("/centralKitchenForSchool/userDelete", hdl.CentralKitchenForSchoolUserDelete) //"央厨-学校"用户删除

	r.POST("/centralKitchenForSchool/studentList", hdl.CentralKitchenForSchoolStudentList)           //"央厨-学校"学生列表
	r.POST("/centralKitchenForSchool/studentUpdate", hdl.CentralKitchenForSchoolStudentUpdate)       //"央厨-学校"学生编辑
	r.POST("/centralKitchenForSchool/studentDelete", hdl.CentralKitchenForSchoolStudentDelete)       //"央厨-学校"学生删除
	r.POST("/centralKitchenForSchool/studentAdmission", hdl.CentralKitchenForSchoolStudentAdmission) //"央厨-学校"学生升学
	r.POST("/centralKitchenForSchool/teacherList", hdl.CentralKitchenForSchoolTeacherList)           //"央厨-学校"教师列表
	r.POST("/centralKitchenForSchool/teacherUpdate", hdl.CentralKitchenForSchoolTeacherUpdate)       //"央厨-学校"教师编辑
	r.POST("/centralKitchenForSchool/teacherDelete", hdl.CentralKitchenForSchoolTeacherDelete)       //"央厨-学校"教师删除
	r.POST("/centralKitchenForSchool/gradeList", hdl.CentralKitchenForSchoolGradeList)               //"央厨-学校"年级列表
	r.DELETE("/centralKitchenForSchool/gradeDelete/:id", hdl.CentralKitchenForSchoolGradeDelete)     //"央厨-学校"年级删除
	r.POST("/centralKitchenForSchool/classList", hdl.CentralKitchenForSchoolClassList)               //"央厨-学校"班级列表
	r.DELETE("/centralKitchenForSchool/classDelete/:id", hdl.CentralKitchenForSchoolClassDelete)     //"央厨-学校"班级删除
	r.POST("/centralKitchenForSchool/ordList", hdl.CentralKitchenForSchoolOrdList)                   //"央厨-学校"订单列表
	r.GET("/centralKitchenForSchool/ordDetail", hdl.CentralKitchenForSchoolOrdDetail)                //"央厨-学校"订单详情
	r.POST("/centralKitchenForSchool/ordRefund", hdl.CentralKitchenForSchoolOrdRefund)               //"央厨-学校"订单退款
	r.POST("/centralKitchenForSchool/batchAskForLeave", hdl.CentralKitchenForSchoolBatchAskForLeave) //"央厨-学校"批量请假
	r.POST("/centralKitchenForSchool/reserveList", hdl.CentralKitchenForSchoolReserveList)           //"央厨-学校"预定列表
	r.GET("/centralKitchenForSchool/reserveDetail", hdl.CentralKitchenForSchoolReserveDetail)        //"央厨-学校"预定详情

	r.POST("/centralKitchenForSchoolOrderRefundList", hdl2.CentralKitchenForSchoolOrderRefundList) //"央厨-学校"订单退款列表
	//r.POST("/centralKitchenForSchoolOrderRefundAudit", hdl2.CentralKitchenForSchoolOrderRefundAudit) //"央厨-学校"订单退款审核

	r.POST("/setBasicCentralKitchenForSchool", hdl.SetBasicCentralKitchenForSchool)                 //"央厨-学校"设置基础设置
	r.GET("/getBasicCentralKitchenForSchool", hdl.GetBasicCentralKitchenForSchool)                  //"央厨-学校"获取基础设置
	r.POST("/setCentralKitchenForSchoolWithSpec", hdl.SetCentralKitchenForSchoolWithSpec)           //设置"央厨-学校-规格"
	r.GET("/getCentralKitchenForSchoolWithSpec", hdl.GetCentralKitchenForSchoolWithSpec)            //获取"央厨-学校-规格"
	r.POST("/listCentralKitchenForSchoolPackage", hdl.ListCentralKitchenForSchoolPackage)           //"央厨-学校-套餐" 列表
	r.GET("/detailCentralKitchenForSchoolPackage", hdl.DetailCentralKitchenForSchoolPackage)        //"央厨-学校-套餐" 详情
	r.POST("/saveCentralKitchenForSchoolPackage", hdl.SaveCentralKitchenForSchoolPackage)           //新增/编辑 "央厨-学校-套餐"
	r.DELETE("/deleteCentralKitchenForSchoolPackage/:id", hdl.DeleteCentralKitchenForSchoolPackage) //删除 "央厨-学校-套餐"

	r.POST("/selfSupportForSchool/userUpdate", hdl.SelfSupportForSchoolUserUpdate)                      //"自营-学校"用户编辑
	r.POST("/selfSupportForSchool/userDelete", hdl.SelfSupportForSchoolUserDelete)                      //"自营-学校"用户删除
	r.POST("/selfSupportForSchool/studentList", hdl.SelfSupportForSchoolStudentList)                    //"自营-学校"学生列表
	r.POST("/selfSupportForSchool/studentUpdate", hdl.SelfSupportForSchoolStudentUpdate)                //"自营-学校"学生编辑
	r.POST("/selfSupportForSchool/studentDelete", hdl.SelfSupportForSchoolStudentDelete)                //"自营-学校"学生删除
	r.POST("/selfSupportForSchool/studentAdmission", hdl.SelfSupportForSchoolStudentAdmission)          //"自营-学校"学生升学
	r.POST("/selfSupportForSchool/teacherList", hdl.SelfSupportForSchoolTeacherList)                    //"自营-学校"教师列表
	r.POST("/selfSupportForSchool/teacherUpdate", hdl.SelfSupportForSchoolTeacherUpdate)                //"自营-学校"教师编辑
	r.POST("/selfSupportForSchool/teacherDelete", hdl.SelfSupportForSchoolTeacherDelete)                //"自营-学校"教师删除
	r.POST("/selfSupportForSchool/workerList", hdl.SelfSupportForSchoolWorkerList)                      //"自营-学校"工作人员列表
	r.POST("/selfSupportForSchool/workerUpdate", hdl.SelfSupportForSchoolWorkerUpdate)                  //"自营-学校"工作人员编辑
	r.POST("/selfSupportForSchool/workerDelete", hdl.SelfSupportForSchoolWorkerDelete)                  //"自营-学校"工作人员删除
	r.POST("/selfSupportForSchool/gradeList", hdl.SelfSupportForSchoolGradeList)                        //"自营-学校"年级列表
	r.DELETE("/selfSupportForSchool/gradeDelete/:id", hdl.SelfSupportForSchoolGradeDelete)              //"自营-学校"年级删除
	r.POST("/selfSupportForSchool/classList", hdl.SelfSupportForSchoolClassList)                        //"自营-学校"班级列表
	r.DELETE("/selfSupportForSchool/classDelete/:id", hdl.SelfSupportForSchoolClassDelete)              //"自营-学校"班级删除
	r.POST("/selfSupportForSchool/addWorker", hdl.SelfSupportForSchoolAddWorker)                        //"自营-学校"添加工作人员
	r.POST("/selfSupportForSchool/addTeacher", hdl.SelfSupportForSchoolAddTeacher)                      //"自营-学校"添加老师
	r.POST("/selfSupportForSchool/ordList", hdl.SelfSupportForSchoolOrdList)                            //"自营-学校"订单列表
	r.POST("/selfSupportForSchool/arrearsOrdList", hdl.SelfSupportForSchoolArrearsOrdList)              //"自营-学校"订单欠费列表
	r.POST("/selfSupportForSchool/arrearsOrdDebtRepay", hdl.SelfSupportForSchoolArrearsOrdDebtRepay)    //"自营-学校"订单欠费催缴
	r.POST("/selfSupportForSchool/arrearsOrdDebtCancel", hdl.SelfSupportForSchoolArrearsOrdDebtCancel)  //"自营-学校"撤销欠款
	r.GET("/selfSupportForSchool/educateSceneKidsClose", hdl.SelfSupportForSchoolEducateSceneKidsClose) //"自营-学校"人脸识别关闭
	r.GET("/selfSupportForSchool/educateFacepayClose", hdl.SelfSupportForSchoolEducateFacepayClose)     //"自营-学校"刷脸支付关闭
	//r.POST("/selfSupportForSchool/statisticsExport", hdl2.SelfSupportForSchoolDataStatisticsExport)       //"自营-学校-数据统计"-导出
	//r.POST("/selfSupportForSchool/statisticsList", hdl2.SelfSupportForSchoolDataStatisticsList)           //"自营-学校-数据统计"-列表
	//r.DELETE("/selfSupportForSchool/statisticsDelete/:id", hdl2.SelfSupportForSchoolDataStatisticsDelete) //"自营-学校-数据统计"-删除

	r.POST("/nursingHome/userUpdate", hdl.NursingHomeUserUpdate)                        //"养老院"用户编辑
	r.POST("/nursingHome/userDelete", hdl.NursingHomeUserDelete)                        //"养老院"用户删除
	r.POST("/nursingHome/ordList", hdl.NursingHomeOrdList)                              //"养老院"订单列表
	r.GET("/nursingHome/ordDetail", hdl.NursingHomeOrdDetail)                           //"养老院"订单详情
	r.POST("/nursingHome/ordRefund", hdl.NursingHomeOrdRefund)                          //"养老院"订单退款
	r.POST("/nursingHome/reserveList", hdl.NursingHomeReserveList)                      //"养老院"预定列表
	r.GET("/nursingHome/reserveDetail", hdl.NursingHomeReserveDetail)                   //"养老院"预定详情
	r.POST("/nursingHome/orderRefundList", hdl2.CentralKitchenForSchoolOrderRefundList) //"养老院"订单退款列表
	r.POST("/setBasicNursingHome", hdl.SetBasicNursingHome)                             //"养老院"设置基础设置
	r.GET("/getBasicNursingHome", hdl.GetBasicNursingHome)                              //"养老院"获取基础设置
	r.POST("/setNursingHomeWithSpec", hdl.SetNursingHomeWithSpec)                       //设置"养老院-规格"
	r.GET("/getNursingHomeWithSpec", hdl.GetNursingHomeWithSpec)                        //获取"养老院-规格"
	r.POST("/listNursingHomePackage", hdl.ListNursingHomePackage)                       //"养老院-套餐" 列表
	r.GET("/detailNursingHomePackage", hdl.DetailNursingHomePackage)                    //"养老院-套餐" 详情
	r.POST("/saveNursingHomePackage", hdl.SaveNursingHomePackage)                       //新增/编辑 "养老院-套餐"
	r.DELETE("/deleteNursingHomePackage/:id", hdl.DeleteNursingHomePackage)             //删除 "养老院-套餐"
	//r.POST("/nursingHome/statisticsExport", hdl2.NursingHomeDataStatisticsExport)       //"养老院-数据统计"-导出
	//r.POST("/nursingHome/statisticsList", hdl2.NursingHomeDataStatisticsList)           //"养老院-数据统计"-列表
	//r.DELETE("/nursingHome/statisticsDelete/:id", hdl2.NursingHomeDataStatisticsDelete) //"养老院-数据统计"-删除
}

func rRole(r *gin.RouterGroup) {
	r.GET("/roleList", hdl2.RoleList)                                //角色列表
	r.POST("/addRole", hdl2.AddRole)                                 //角色添加
	r.POST("/roleBindPermissionGroup", hdl2.RoleBindPermissionGroup) //角色绑定权限组
	r.POST("/updateRoleState", hdl2.UpdateRoleState)                 //修改角色状态
	r.POST("/updateRole", hdl2.UpdateRole)                           //修改角色状态
	r.DELETE("/deleteRole/:id", hdl2.DeleteRole)                     //删除角色
	r.GET("/permissionGroupList", hdl2.PermissionGroupList)          //权限组列表
	r.POST("/adminList", hdl2.AdminList)                             //管理员列表
	r.POST("/updateAdminState", hdl2.UpdateAdminState)               //修改管理员状态
	r.POST("/updateAdmin", hdl2.UpdateAdmin)                         //修改管理员信息
	r.POST("/addAdmin", hdl2.AddAdmin)                               //新增管理员
	r.DELETE("/deleteAdmin/:adm_id", hdl2.DeleteAdmin)               //删除管理员
	r.GET("/adminInfo", hdl2.AdminInfo)                              //获取管理员信息
	r.POST("/bindAdminRole", hdl2.BindAdminRole)                     //绑定角色
}

func AdminRoute(r *gin.RouterGroup) {
	r.GET("/demo", hdl2.Demo)

	r.POST("/login", hdl2.Login)

	r.Use(mw.Auth)                    //检测登录状态
	r.GET("/userInfo", hdl2.UserInfo) //用户信息
	r.Any("/changePwd", hdl2.Demo)    //修改密码
	r.GET("/sysCfg", hdl2.GetSysCfg)  //基础配置-获取

	r.Use(mw.CheckPermission) //检测权限
	rOss(r.Group("/oss"))
	rComm(r.Group("/comm"))
	rHomePage(r.Group("/homePage"))                 //首页
	rCompany(r.Group("/company"))                   //公司管理
	rNotice(r.Group("/notice"))                     //公告管理
	rBanner(r.Group("/banner"))                     //轮播图管理
	rEnterprise(r.Group("/enterprise"))             //校企管理
	rEnterpriseManage(r.Group("/enterpriseManage")) //校企管理详情
	rRole(r.Group("/role"))                         //权限管理
	rSetCenter(r.Group("/setCenter"))               //设置中心
	rUser(r.Group("/user"))                         //用户管理
	rAuditCenter(r.Group("/auditCenter"))           //审核中心
	rFinanceManage(r.Group("/financeManage"))       //财务管理
	rDataStatistics(r.Group("/dataStatistics"))     //数据统计
}
